==> rn-adaptbyte-0.5.4.tgz: package/src/components/molecule/button/Button.tsx <==
import React, { useState } from 'react';
import { Platform, Pressable, View } from 'react-native';
import { BORDERRADIUS } from '../../../assets/theme';
import { Spacer } from '../../atom/divider';
import { Typography } from '../../atom';
import type { ButtonProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import LinearGradient from 'react-native-linear-gradient';

const Button = ({
  title,
  variant = 'large',
  mode = 'normal',
  flexGrow = 1,
  isLoading = false,
  loadingMessage = 'Loading',
  trailingIcon,
  leadingIcon,
  width = '100%',
  height = 'auto',
  colorText,
  disabled = false,
  onPress,
  spaceIcon = false,
  borderRadius = BORDERRADIUS.radius_40,
  backgroundColor,
  fontSize,
  style,
  contentStyle,
  linearGradientConfig,
  textConfig,
  // type = 'normal',
  ...props
}: ButtonProps) => {
  const { styles, theme } = useStyles(stylesheet);
  backgroundColor = backgroundColor || theme.adaptbyte.colors.button.primary;

  const [isPressed, setIsPressed] = useState(false);

  const styled = [
    styles.btn,
    { backgroundColor },
    styles[`btn-${variant}`],
    { width, height },
    styles[`btn-mode-${mode}`],
    isPressed ? styles.btnPressed : null,
    isLoading ? styles.btnLoading : null,
    disabled ? styles[`btn-mode-disabled`] : null,
    { borderRadius },
  ];

  const textMode = () => {
    if (disabled) return 'disabled';
    return mode;
  };

  const textStyles = [
    styles.btnText,
    styles[`btn-text-${variant}`],
    styles[`btn-text-mode-${textMode()}`],
    colorText
      ? { color: isPressed ? theme.adaptbyte.colors.shade.white : colorText }
      : undefined,
    fontSize ? { fontSize } : undefined,
  ];

  const gradientConfig = () => {
    if (Platform.OS === 'ios') {
      return {
        color: [
          theme.adaptbyte.colors.button.linearGradient.color1,
          theme.adaptbyte.colors.button.linearGradient.color2,
        ],
        location: [1, 0.1],
      };
    }

    return {
      color: [
        theme.adaptbyte.colors.button.linearGradient.color2,
        theme.adaptbyte.colors.button.linearGradient.color1,
      ],
      location: [0, 1],
    };
  };

  const renderContent = () => {
    return (
      <>
        {leadingIcon && spaceIcon && <Spacer flexGrow={flexGrow} />}
        {leadingIcon && <View style={styles.iconContainer}>{leadingIcon}</View>}
        {(leadingIcon || trailingIcon) && spaceIcon && (
          <Spacer flexGrow={flexGrow} />
        )}

        <Typography.Paragraph
          text={isLoading ? loadingMessage : title}
          weight="bold"
          style={textStyles as never}
          align="center"
          {...textConfig}
        />

        {(leadingIcon || trailingIcon) && spaceIcon && (
          <Spacer flexGrow={flexGrow} />
        )}
        {trailingIcon && (
          <View style={styles.iconContainer}>{trailingIcon}</View>
        )}
      </>
    );
  };

  if (mode === 'linear-gradient' && !disabled) {
    return (
      <Pressable
        onPress={onPress}
        style={[styles.containerGradient, style]}
        onPressIn={() => setIsPressed(true)}
        onPressOut={() => setIsPressed(false)}
        disabled={isLoading || disabled}
      >
        <LinearGradient
          colors={gradientConfig()?.color}
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={[styles.btn, { borderRadius, opacity: isPressed ? 0.8 : 1 }]}
          locations={gradientConfig()?.location}
          {...linearGradientConfig}
        >
          <View
            style={[
              styles[`btn-${variant}`],
              styles['btn-mode-linear-gradient'],
              contentStyle,
            ]}
          >
            {renderContent()}
          </View>
        </LinearGradient>
      </Pressable>
    );
  }

  return (
    <Pressable
      onPress={onPress}
      style={[styled, style]}
      onPressIn={() => setIsPressed(true)}
      onPressOut={() => setIsPressed(false)}
      disabled={isLoading || disabled}
      {...props}
    >
      {renderContent()}
    </Pressable>
  );
};

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Base
   */
  'containerGradient': {
    width: '100%',
  },
  'btn': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  'btnText': {
    color: theme.adaptbyte.colors.primaryWhiteHex,
    marginHorizontal: theme.adaptbyte.spacing.space_8,
  },
  'iconContainer': {
    marginRight: 2,
  },

  /**
   * Button Variants
   */
  'btn-large': {
    paddingVertical: theme.adaptbyte.spacing.space_16,
    paddingHorizontal: theme.adaptbyte.spacing.space_32,
  },
  'btn-medium': {
    paddingVertical: theme.adaptbyte.spacing.space_12,
    paddingHorizontal: theme.adaptbyte.spacing.space_24,
  },
  'btn-small': {
    paddingVertical: theme.adaptbyte.spacing.space_8,
    paddingHorizontal: theme.adaptbyte.spacing.space_16,
  },

  /**
   * Button text variant
   */
  'btn-text-large': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize,
  },
  'btn-text-medium': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize,
  },
  'btn-text-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-01'].fontSize,
  },

  /**
   * Button state
   */
  'btnPressed': {
    backgroundColor: theme.adaptbyte.colors.primary._700,
  },
  'btnLoading': {
    backgroundColor: theme.adaptbyte.colors.button.hover,
  },
  'btnDisabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled,
  },

  /**
   * Mode
   */
  'btn-mode-outlined': {
    backgroundColor: 'transparent',
    borderColor: theme.adaptbyte.colors.button.primary,
    borderWidth: 1,
  },
  'btn-mode-normal': {},
  'btn-mode-disabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled,
  },
  'btn-mode-light': {
    backgroundColor: 'transparent',
    borderWidth: 0,
  },
  'btn-mode-red': {
    backgroundColor: theme.adaptbyte.colors.error._900,
    borderWidth: 0,
  },
  'btn-mode-linear-gradient': {},

  /**
   * Text Color
   */
  'btn-text-mode-outlined': {
    color: theme.adaptbyte.colors.button.primary,
  },
  'btn-text-mode-normal': {
    color: theme.adaptbyte.colors.button.textNormal,
  },
  'btn-text-mode-disabled': {
    color: theme.adaptbyte.colors.button.textDisabled,
  },
  'btn-text-mode-light': {
    color: theme.adaptbyte.colors.button.primary,
  },
  'btn-text-mode-red': {
    color: theme.adaptbyte.colors.shade.white,
  },
  'btn-text-mode-linear-gradient': {
    color: theme.adaptbyte.colors.button.textNormal,
  },
}));

export default Button;

==> rn-adaptbyte-0.5.5.tgz: package/src/components/molecule/button/Button.tsx <==
import React, { useState } from 'react';
import { Platform, Pressable, View } from 'react-native';
import { BORDERRADIUS } from '../../../assets/theme';
import { Spacer } from '../../atom/divider';
import { Typography } from '../../atom';
import type { ButtonProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import LinearGradient from 'react-native-linear-gradient';

const Button = ({
  title,
  variant = 'large',
  mode = 'normal',
  flexGrow = 1,
  isLoading = false,
  loadingMessage = 'Loading',
  trailingIcon,
  leadingIcon,
  width = '100%',
  height = 'auto',
  colorText,
  disabled = false,
  onPress,
  spaceIcon = false,
  borderRadius = BORDERRADIUS.radius_40,
  backgroundColor,
  fontSize,
  style,
  contentStyle,
  linearGradientConfig,
  textConfig,
  borderColor,
  spaceIconH,
  spaceIconW,
  pressedStyle,
  // type = 'normal',
  ...props
}: ButtonProps) => {
  const { styles, theme } = useStyles(stylesheet);
  backgroundColor = backgroundColor || theme.adaptbyte.colors.button.primary;

  const [isPressed, setIsPressed] = useState(false);
  const borderColorOutlined =
    mode === 'outlined' && !borderColor
      ? theme.adaptbyte.colors.button.primary
      : borderColor;
  const styled = [
    styles.btn,
    { backgroundColor },
    styles[`btn-${variant}`],
    { width, height },
    styles[`btn-mode-${mode}`],
    isPressed ? pressedStyle || styles.btnPressed : null,
    isLoading ? styles.btnLoading : null,
    disabled ? styles[`btn-mode-disabled`] : null,
    { borderRadius, borderColorOutlined },
  ];

  const textMode = () => {
    if (disabled) return 'disabled';
    return mode;
  };

  const textStyles = [
    styles.btnText,
    styles[`btn-text-${variant}`],
    styles[`btn-text-mode-${textMode()}`],
    textConfig?.color || colorText
      ? {
          color: isPressed
            ? theme.adaptbyte.colors.shade.white
            : textConfig?.color || colorText,
        }
      : undefined,
    fontSize ? { fontSize } : undefined,
    spaceIconH || spaceIconW ? { marginHorizontal: undefined } : undefined,
  ];

  const gradientConfig = () => {
    if (Platform.OS === 'ios') {
      return {
        color: [
          theme.adaptbyte.colors.button.linearGradient.color1,
          theme.adaptbyte.colors.button.linearGradient.color2,
        ],
        location: [1, 0.1],
      };
    }

    return {
      color: [
        theme.adaptbyte.colors.button.linearGradient.color2,
        theme.adaptbyte.colors.button.linearGradient.color1,
      ],
      location: [0, 1],
    };
  };

  const renderContent = () => {
    const spaceSizeIcon = {
      flexGrow: !(spaceIconH || spaceIconW) ? flexGrow : undefined,
      height: spaceIconH,
      width: spaceIconW,
    };
    return (
      <>
        {leadingIcon && spaceIcon && <Spacer {...spaceSizeIcon} />}
        {leadingIcon && <View style={styles.iconContainer}>{leadingIcon}</View>}
        {(leadingIcon || trailingIcon) && spaceIcon && (
          <Spacer {...spaceSizeIcon} />
        )}

        <Typography.Paragraph
          text={isLoading ? loadingMessage : title}
          weight="bold"
          style={textStyles as never}
          align="center"
          {...textConfig}
        />

        {(leadingIcon || trailingIcon) && spaceIcon && (
          <Spacer {...spaceSizeIcon} />
        )}
        {trailingIcon && (
          <View style={styles.iconContainer}>{trailingIcon}</View>
        )}
      </>
    );
  };

  if (mode === 'linear-gradient' && !disabled) {
    return (
      <Pressable
        onPress={onPress}
        style={[styles.containerGradient, style]}
        onPressIn={() => setIsPressed(true)}
        onPressOut={() => setIsPressed(false)}
        disabled={isLoading || disabled}
      >
        <LinearGradient
          colors={gradientConfig()?.color}
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={[styles.btn, { borderRadius, opacity: isPressed ? 0.8 : 1 }]}
          locations={gradientConfig()?.location}
          {...linearGradientConfig}
        >
          <View
            style={[
              styles[`btn-${variant}`],
              styles['btn-mode-linear-gradient'],
              contentStyle,
            ]}
          >
            {renderContent()}
          </View>
        </LinearGradient>
      </Pressable>
    );
  }

  return (
    <Pressable
      onPress={onPress}
      style={[styled, style]}
      onPressIn={() => setIsPressed(true)}
      onPressOut={() => setIsPressed(false)}
      disabled={isLoading || disabled}
      {...props}
    >
      {renderContent()}
    </Pressable>
  );
};

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Base
   */
  'containerGradient': {
    width: '100%',
  },
  'btn': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  'btnText': {
    color: theme.adaptbyte.colors.primaryWhiteHex,
    marginHorizontal: theme.adaptbyte.spacing.space_8,
  },
  'iconContainer': {
    marginRight: 2,
  },

  /**
   * Button Variants
   */
  'btn-large': {
    paddingVertical: theme.adaptbyte.spacing.space_16,
    paddingHorizontal: theme.adaptbyte.spacing.space_32,
  },
  'btn-medium': {
    paddingVertical: theme.adaptbyte.spacing.space_12,
    paddingHorizontal: theme.adaptbyte.spacing.space_24,
  },
  'btn-small': {
    paddingVertical: theme.adaptbyte.spacing.space_8,
    paddingHorizontal: theme.adaptbyte.spacing.space_16,
  },

  /**
   * Button text variant
   */
  'btn-text-large': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize,
  },
  'btn-text-medium': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize,
  },
  'btn-text-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-01'].fontSize,
  },

  /**
   * Button state
   */
  'btnPressed': {
    backgroundColor: theme.adaptbyte.colors.primary._700,
  },
  'btnLoading': {
    backgroundColor: theme.adaptbyte.colors.button.hover,
  },
  'btnDisabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled,
  },

  /**
   * Mode
   */
  'btn-mode-outlined': {
    backgroundColor: 'transparent',
    borderColor: theme.adaptbyte.colors.button.primary,
    borderWidth: 1,
  },
  'btn-mode-normal': {},
  'btn-mode-disabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled,
  },
  'btn-mode-light': {
    backgroundColor: 'transparent',
    borderWidth: 0,
  },
  'btn-mode-red': {
    backgroundColor: theme.adaptbyte.colors.error._900,
    borderWidth: 0,
  },
  'btn-mode-linear-gradient': {},

  /**
   * Text Color
   */
  'btn-text-mode-outlined': {
    color: theme.adaptbyte.colors.button.primary,
  },
  'btn-text-mode-normal': {
    color: theme.adaptbyte.colors.button.textNormal,
  },
  'btn-text-mode-disabled': {
    color: theme.adaptbyte.colors.button.textDisabled,
  },
  'btn-text-mode-light': {
    color: theme.adaptbyte.colors.button.primary,
  },
  'btn-text-mode-red': {
    color: theme.adaptbyte.colors.shade.white,
  },
  'btn-text-mode-linear-gradient': {
    color: theme.adaptbyte.colors.button.textNormal,
  },
}));

export default Button;
